@@ -191,6 +191,18 @@ class FireSmokeUseCase(BaseProcessor):
                     frame_number = start_frame
 
              # Step 7: alerts
+            print("-----------------------------------------------")
+            print(config.confidence_threshold)
+            print(config.fire_smoke_categories)
+            print(config.index_to_category)
+            print(config.target_categories)
+            print(config.threshold_area)
+            print(config.alert_config)
+            print(config.alert_config.count_thresholds)
+            print(config.alert_config.alert_type)
+            print(config.alert_config.alert_value)
+            print(config.alert_config.alert_incident_category)
+            print("-----------------------------------------------")
 
             alerts = self._check_alerts(fire_smoke_summary, frame_number, config, stream_info)
 
@@ -282,7 +294,11 @@ class FireSmokeUseCase(BaseProcessor):
         if hasattr(config.alert_config, 'count_thresholds') and config.alert_config.count_thresholds:
             alert_id = self._get_alert_incident_ids(self._ascending_alert_list[-1:])
 
-            for category, threshold in config.alert_config.count_thresholds.items():
+            count_thresholds = {}
+            if config.alert_config and hasattr(config.alert_config, "count_thresholds"):
+                count_thresholds = config.alert_config.count_thresholds or {}
+
+            for category, threshold in count_thresholds.items():
                 if category == "all" and total > threshold:  
                     
                     alerts.append({
@@ -360,8 +376,14 @@ class FireSmokeUseCase(BaseProcessor):
         if total > 0:
            # Calculate total bbox area
             total_area = 0.0
-        
-            for category, threshold in config.alert_config.count_thresholds.items():
+            # Safely retrieve count thresholds. If alert_config is None (e.g., when it
+            # is not provided or failed to parse) we default to an empty mapping so
+            # the subsequent logic can still execute without raising an AttributeError.
+            count_thresholds = {}
+            if config.alert_config and hasattr(config.alert_config, "count_thresholds"):
+                count_thresholds = config.alert_config.count_thresholds or {}
+
+            for category, threshold in count_thresholds.items():
                 if category in summary.get("per_category_count", {}):
                     
                     #count = summary.get("per_category_count", {})[category]
@@ -583,6 +605,26 @@ class FireSmokeUseCase(BaseProcessor):
 
 
         tracking_stats.append(tracking_stat)
+
+        if len(self.id_hit_list)==1:
+            last_ending_id = self._get_alert_incident_ids("")
+            if last_ending_id==5:
+                tracking_stats.append({
+                            "alert_type": getattr(config.alert_config, 'alert_type', ['Default']) if hasattr(config.alert_config, 'alert_type') else ['Default'],
+                            "alert_id": "alert_"+category+'_'+str(last_ending_id),
+                            "incident_category": self.CASE_TYPE,
+                            "threshold_level": 0,
+                            "ascending": False,
+                            "settings": {t: v for t, v in zip(getattr(config.alert_config, 'alert_type', ['Default']) if hasattr(config.alert_config, 'alert_type') else ['Default'],
+                                     getattr(config.alert_config, 'alert_value', ['JSON']) if hasattr(config.alert_config, 'alert_value') else ['JSON'])
+                                    }       
+                        })
+                tracking_stats.append(self.create_incident(incident_id=self.CASE_TYPE+'_'+str(last_ending_id), incident_type=self.CASE_TYPE,
+                            severity_level='info', human_text='Event Over', camera_info=camera_info, alerts=alerts, alert_settings=alert_settings,
+                            start_time=start_timestamp, end_time='Incident still active',
+                            level_settings= {"low": 3, "medium": 5, "significant":15, "critical": 30}))
+                
+        
         return tracking_stats
 
     def _generate_summary(
@@ -952,6 +994,9 @@ class FireSmokeUseCase(BaseProcessor):
             if len(self.id_hit_list)==1:
                 self.id_hit_counter+=1
                 if self.id_hit_counter>120:
+                    self.id_hit_list = ["low","medium","significant","critical","low"]
+                    self.id_hit_counter = 0
+                    self.latest_stack = None
                     return int(5)
                 if sev_level==self.latest_stack:
                     return int(5-len(self.id_hit_list))
